# FRAG format

This is an format for the fragment files defined by 10x genomics to
store the alignments from single-cell ATAC-seq experiment. It can be
regarded as the `BEDPE` format, containing the chromosome, the
leftmost position of aligned fragment, and the rightmost position of
the aligned fragment, with two extra columns -- the barcode information and
the counts of the fragments aligned to the same location with the same
barcode. It is usually generated by the `cellranger-atac` or
`cellranger-arc` pipeline. But this is a fairly straightforward format
so one can easily convert other alignment results into this format. An
example of the fragment file is like:
	
```
chr22   10768839        10769063        AAACGAAAGACTCGGA     2
chr22   11333072        11333249        AAACGAAAGACTCGGA     1
chr22   11363891        11364010        AAACGAAAGACTCGGA     1
...
```
